@@ -66,7 +66,9 @@ def mqtt_connected(func):
     def wrapper(self, *args, **kwargs):
         if not self._connected_state.is_set():
             base_logger.warning("Client not connected, waiting for it")
-            asyncio.wait([self._connected_state.wait(), self._no_more_connections.wait()], return_when=asyncio.FIRST_COMPLETED)
+            _, pending = yield from asyncio.wait([self._connected_state.wait(), self._no_more_connections.wait()], return_when=asyncio.FIRST_COMPLETED)
+            for t in pending:
+                t.cancel()
             if self._no_more_connections.is_set():
                 raise ClientException("Will not reconnect")
         return (yield from func(self, *args, **kwargs))
@@ -106,6 +108,7 @@ class MQTTClient:
         self._disconnect_task = None
         self._connected_state = asyncio.Event(loop=self._loop)
         self._no_more_connections = asyncio.Event(loop=self._loop)
+        self.extra_headers = {}
 
         # Init plugins manager
         context = ClientContext()
@@ -119,7 +122,8 @@ class MQTTClient:
                 cleansession=None,
                 cafile=None,
                 capath=None,
-                cadata=None):
+                cadata=None,
+                extra_headers={}):
         """
             Connect to a remote broker.
 
@@ -132,11 +136,13 @@ class MQTTClient:
             :param cafile: server certificate authority file (optional, used for secured connection)
             :param capath: server certificate authority path (optional, used for secured connection)
             :param cadata: server certificate authority data (optional, used for secured connection)
+            :param extra_headers: a dictionary with additional http headers that should be sent on the initial connection (optional, used only with websocket connections)
             :return: `CONNACK <http://docs.oasis-open.org/mqtt/mqtt/v3.1.1/os/mqtt-v3.1.1-os.html#_Toc398718033>`_ return code
             :raise: :class:`hbmqtt.client.ConnectException` if connection fails
         """
 
         self.session = self._initsession(uri, cleansession, cafile, capath, cadata)
+        self.extra_headers = extra_headers;
         self.logger.debug("Connect to: %s" % uri)
 
         try:
@@ -158,7 +164,7 @@ class MQTTClient:
 
             This method is a *coroutine*.
         """
-
+        yield from self.cancel_tasks()
         if self.session.transitions.is_connected():
             if not self._disconnect_task.done():
                 self._disconnect_task.cancel()
@@ -169,6 +175,19 @@ class MQTTClient:
         else:
             self.logger.warning("Client session is not currently connected, ignoring call")
 
+    @asyncio.coroutine
+    def cancel_tasks(self):
+        """
+        Before disconnection need to cancel all pending tasks
+        :return:
+        """
+        try:
+            while True:
+                task = self.client_tasks.pop()
+                task.cancel()
+        except IndexError as err:
+            pass
+
     @asyncio.coroutine
     def reconnect(self, cleansession=None):
         """
@@ -201,7 +220,7 @@ class MQTTClient:
                 return (yield from self._do_connect())
             except BaseException as e:
                 self.logger.warning("Reconnection attempt failed: %r" % e)
-                if nb_attempt > reconnect_retries:
+                if reconnect_retries >= 0 and nb_attempt > reconnect_retries:
                     self.logger.error("Maximum number of connection attempts reached. Reconnection aborted")
                     raise ConnectException("Too many connection attempts failed")
                 exp = 2 ** nb_attempt
@@ -235,7 +254,7 @@ class MQTTClient:
 
     @mqtt_connected
     @asyncio.coroutine
-    def publish(self, topic, message, qos=None, retain=None):
+    def publish(self, topic, message, qos=None, retain=None, ack_timeout=None):
         """
             Publish a message to the broker.
 
@@ -269,7 +288,7 @@ class MQTTClient:
                     pass
             return _qos, _retain
         (app_qos, app_retain) = get_retain_and_qos()
-        return (yield from self._handler.mqtt_publish(topic, message, app_qos, app_retain))
+        return (yield from self._handler.mqtt_publish(topic, message, app_qos, app_retain, ack_timeout))
 
     @mqtt_connected
     @asyncio.coroutine
@@ -395,6 +414,7 @@ class MQTTClient:
                     self.session.broker_uri,
                     subprotocols=['mqtt'],
                     loop=self._loop,
+                    extra_headers=self.extra_headers,
                     **kwargs)
                 reader = WebSocketsReader(websocket)
                 writer = WebSocketsWriter(websocket)
