@@ -24,7 +24,9 @@ config = {
         'plugins': [
             'auth_file', 'auth_anonymous'
         ]
-
+    },
+    'topic-check': {
+        'enabled': False
     }
 }
 
