@@ -1,10 +1,10 @@
 # Copyright (c) 2015 Nicolas JOUANIN
 #
 # See the file license.txt for copying permission.
+import asyncio
 import unittest
 
 from hbmqtt.mqtt.puback import PubackPacket, PacketIdVariableHeader
-from hbmqtt.codecs import *
 from hbmqtt.adapters import BufferReader
 
 
