@@ -1,11 +1,11 @@
 # Copyright (c) 2015 Nicolas JOUANIN
 #
 # See the file license.txt for copying permission.
+import asyncio
 import unittest
 
 from hbmqtt.mqtt.pubcomp import PubcompPacket, PacketIdVariableHeader
 from hbmqtt.adapters import BufferReader
-from hbmqtt.codecs import *
 
 
 class PubcompPacketTest(unittest.TestCase):
