@@ -1,10 +1,10 @@
 # Copyright (c) 2015 Nicolas JOUANIN
 #
 # See the file license.txt for copying permission.
+import asyncio
 import unittest
 
 from hbmqtt.mqtt.pubrel import PubrelPacket, PacketIdVariableHeader
-from hbmqtt.codecs import *
 from hbmqtt.adapters import BufferReader
 
 
@@ -22,4 +22,4 @@ class PubrelPacketTest(unittest.TestCase):
         variable_header = PacketIdVariableHeader(10)
         publish = PubrelPacket(variable_header=variable_header)
         out = publish.to_bytes()
-        self.assertEqual(out, b'\x62\x02\x00\x0a')
\ No newline at end of file
+        self.assertEqual(out, b'\x62\x02\x00\x0a')
