@@ -1,12 +1,12 @@
 # Copyright (c) 2015 Nicolas JOUANIN
 #
 # See the file license.txt for copying permission.
+import asyncio
 import unittest
 
 from hbmqtt.mqtt.subscribe import SubscribePacket, SubscribePayload
 from hbmqtt.mqtt.packet import PacketIdVariableHeader
-from hbmqtt.mqtt.constants import *
-from hbmqtt.codecs import *
+from hbmqtt.mqtt.constants import QOS_1, QOS_2
 from hbmqtt.adapters import BufferReader
 
 
